@@ -42,6 +42,12 @@ sub put {
   # return $obj->put(@_);
 }
 
+# NG 12-10-28: redispatch UNIVERSAL methods to Oid's class
+sub isa {shift->{_CLASS}->isa(@_)}
+sub can {shift->{_CLASS}->can(@_)}
+sub DOES {shift->{_CLASS}->DOES(@_)}
+sub VERSION {shift->{_CLASS}->VERSION(@_)}
+
 # NG 10-09-09: decided to remove is_extant, is_deleted, del to avoid polluting namespace further
 # # NG 10-08-27: part of support for deleted objects
 # #              have to fetch object since that's the only way to know whether it's deleted.
@@ -118,15 +124,13 @@ sub stringify {
   my $obj=Class::AutoDB::Serialize::fetch($oid);
   "$obj";
 }
-# Code below adapted from Graph v0.67
 # NG 10-09-11: removed eq, ne. Perl autogenerates from stringify
 # NG 10-09-11: changed bool to force fetch
-# sub eq {"$_[0]" eq "$_[1]"}
-# sub ne {"$_[0]" ne "$_[1]"}
+# NG 10-09-17: added '0+' (convert to number), since Perls >= 5.10 stringify objects otherwise
 use overload
   '""' => \&stringify,
+  '0+' => sub {refaddr($_[0])},
   'bool'=>sub {length(stringify($_[0]))>0},
-  # 'eq' => \&eq,
-  # 'ne' => \&ne,
   fallback => 'TRUE';
 ####################
+1;
